/* memxor.h
 *
 */

#ifndef LSH_MEMXOR_H_INCLUDED
#define LSH_MEMXOR_H_INCLUDED

#include "lsh_types.h"

#include <stdlib.h>

uint8_t *memxor(uint8_t *dst, const uint8_t *src, size_t n);

#endif /* LSH_MEMXOR_H_INCLUDED */
